@@ -10,10 +10,11 @@ use vars qw( $VERSION @ISA @EXPORT );
 *_fail_msg = *Carp::Assert::_fail_msg;
 
 BEGIN {
-    $VERSION = '0.02';
+    $VERSION = '0.03';
     @ISA = qw(Exporter);
     @EXPORT = qw( 
 	assert_defined
+	assert_fail
 	assert_isa
 	assert_nonref
 	assert_nonblank
@@ -33,7 +34,7 @@ Carp::Assert::More - convenience wrappers around Carp::Assert
 
 =head1 DESCRIPTION
 
-Carp::Assert::More is a set of wrappers around the Carp::Assert functions
+Carp::Assert::More is a set of wrappers around the L<Carp::Assert> functions
 to make the habit of writing assertions even easier.
 
 Everything in here is effectively syntactic sugar.  There's no technical
@@ -58,12 +59,25 @@ Many more functions.  This is just the first proof of concept.
 =head1 CAVEATS
 
 I haven't specifically done anything to make Carp::Assert::More be
-backwards compatible with anything besides 5.6.1, much less back to 5.004.
-Perhaps someone with better testing resources in that area can help me
-out here.
+backwards compatible with anything besides Perl 5.6.1, much less back
+to 5.004.  Perhaps someone with better testing resources in that area
+can help me out here.
 
 =head1 FUNCTIONS
 
+=head2 assert_fail( [$name] )
+
+Assertion that always fails.  C<assert_fail($msg)> is exactly the same
+as calling C<assert(0,$msg)>, but it eliminates that case where you
+accidentally use C<assert($msg)>, which of course never fires.
+
+=cut
+
+sub assert_fail(;$) {
+    require Carp;
+    &Carp::confess( _fail_msg($_[0]) );
+}
+
 =head2 assert_defined( $this [, $name] )
 
 Asserts that I<$this> is defined.
